@@ -41,3 +41,10 @@ guardExecution <- function(yourExpression_ex, functionName_s_1 = 'no function na
   brv(TRUE, rv, '', '')
 }
 
+buildIdentityList <- function(entries_s) {
+  d <- toupper(entries_s)
+  names(d) <- gsub('[^A-Z0-9_]', '', d, perl = TRUE)
+  as.list(d)
+}
+
+
